==> qiskit-experiments-0.3.1.tar.gz: qiskit-experiments-0.3.1/README.md <==
# Qiskit Experiments

[![License](https://img.shields.io/github/license/Qiskit/qiskit-experiments.svg?style=popout-square)](https://opensource.org/licenses/Apache-2.0)

**This repo is still under active development, there will be breaking API changes**

**Qiskit** is an open-source framework for working with noisy quantum computers
at the level of pulses, circuits, and algorithms.

Qiskit Experiments is a repository that builds tools for building, running,
and analysis of experiments on noisy quantum computers.

## Contribution Guidelines

If you'd like to contribute to Qiskit Experiments, please take a look at our
[contribution guidelines](CONTRIBUTING.md). This project adheres to Qiskit's
[code of conduct](CODE_OF_CONDUCT.md). By participating, you are expected to
uphold this code.

We use [GitHub issues](https://github.com/Qiskit/qiskit-experiments/issues) for
tracking requests and bugs. Please
[join the Qiskit Slack community](https://ibm.co/joinqiskitslack)
and use our [Qiskit Slack channel](https://qiskit.slack.com) for discussion and
simple questions.
For questions that are more suited for a forum we use the Qiskit tag in the
[Stack Exchange](https://quantumcomputing.stackexchange.com/questions/tagged/qiskit).

## Authors and Citation

Qiskit Experiments is the work of [many people](https://github.com/Qiskit/qiskit-experiments/graphs/contributors) who contribute
to the project at different levels. If you use Qiskit, please cite as per the included [BibTeX file](https://github.com/Qiskit/qiskit/blob/master/Qiskit.bib).

## License

[Apache License 2.0](LICENSE.txt)

==> qiskit-experiments-0.5.0.tar.gz: qiskit-experiments-0.5.0/README.md <==
# Qiskit Experiments

[![License](https://img.shields.io/github/license/Qiskit/qiskit-experiments.svg?style=popout-square)](https://opensource.org/licenses/Apache-2.0)

**Qiskit Experiments** is a repository that builds tools for building, running,
and analyzing experiments on noisy quantum computers using Qiskit.

To learn more about the package, you can see the 
[most up-to-date documentation](https://qiskit.org/documentation/experiments/dev/) 
corresponding to the main branch of this repository or the 
[documentation for the latest stable release](https://qiskit.org/documentation/experiments).

## Contribution Guidelines

If you'd like to contribute to Qiskit Experiments, please take a look at our
[contribution guidelines](CONTRIBUTING.md). This project adheres to Qiskit's
[code of conduct](CODE_OF_CONDUCT.md). By participating, you are expected to
uphold this code.

We use [GitHub issues](https://github.com/Qiskit/qiskit-experiments/issues) for
tracking requests and bugs. Please
[join the Qiskit Slack community](https://qisk.it/join-slack)
and use the [#experiments](https://qiskit.slack.com/archives/CGZDF48EN) channel for discussion and
simple questions.
For questions that are more suited for a forum we use the Qiskit tag in 
[Stack Exchange](https://quantumcomputing.stackexchange.com/questions/tagged/qiskit).

## Authors and Citation

Qiskit Experiments is the work of [many people](https://github.com/Qiskit/qiskit-experiments/graphs/contributors) who contribute
to the project at different levels. If you use Qiskit, please cite as per the included [BibTeX file](https://github.com/Qiskit/qiskit/blob/master/Qiskit.bib).

## License

[Apache License 2.0](LICENSE.txt)
